<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AccountItem</name>
    <message>
        <source>Sync successful</source>
        <translation type="vanished">同步成功</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation type="vanished">網路異常</translation>
    </message>
    <message>
        <source>Server exception</source>
        <translation type="vanished">伺服器異常</translation>
    </message>
    <message>
        <source>Storage full</source>
        <translation type="vanished">儲存已滿</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>Local account</source>
        <translation type="vanished">本機帳戶</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation type="vanished">日程類型</translation>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <source>Color</source>
        <translation type="vanished">顏色</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">儲 存</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation type="vanished">星期一</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="vanished">星期二</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="vanished">星期三</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="vanished">星期四</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="vanished">星期五</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="vanished">星期六</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">星期日</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">年</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">月</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">日</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="vanished">農曆</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">建立日程</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <source>%1 more</source>
        <translation type="vanished">還有%1項</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation type="vanished">建立日程</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">建立日程</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">年</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <source>My Event</source>
        <translation type="vanished">我的日程</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">確 定</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">刪 除</translation>
    </message>
    <message>
        <source>Edit</source>
        <comment>button</comment>
        <translation type="vanished">編 輯</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <source>New event type</source>
        <translation type="vanished">新增日程類型</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">建立日程</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation type="vanished">編輯日程</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation type="vanished">結束時間需晚於開始時間</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">確 定</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">從不</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation type="vanished">日程開始時</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation type="vanished">15分鐘前</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation type="vanished">30分鐘前</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation type="vanished">1小時前</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation type="vanished">1天前</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation type="vanished">2天前</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation type="vanished">1週前</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation type="vanished">日程發生當天（上午9點）</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation type="vanished">次後</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation type="vanished">名稱不能為空</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation type="vanished">名稱不能設置為全空格，請修改</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="vanished">類型：</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">內容：</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation type="vanished">全天：</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation type="vanished">開始時間：</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation type="vanished">結束時間：</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation type="vanished">提醒：</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="vanished">重複：</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation type="vanished">結束重複：</translation>
    </message>
    <message>
        <source>Calendar account:</source>
        <translation type="vanished">日曆帳戶：</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation type="vanished">日曆帳戶</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">類型</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">內容</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">全天</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation type="vanished">時間：</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">時間</translation>
    </message>
    <message>
        <source>Solar</source>
        <translation type="vanished">公曆</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="vanished">農曆</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation type="vanished">開始時間</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation type="vanished">結束時間</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation type="vanished">提醒</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation type="vanished">重複</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="vanished">每天</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation type="vanished">工作日</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="vanished">每週</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="vanished">每月</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation type="vanished">每年</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation type="vanished">結束重複</translation>
    </message>
    <message>
        <source>After</source>
        <translation type="vanished">於</translation>
    </message>
    <message>
        <source>On</source>
        <translation type="vanished">於日期</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">儲 存</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation type="vanished">重複日程的所有重複必須具有相同的全天狀態。</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation type="vanished">您要更改所有重複嗎？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">取 消</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation type="vanished">全部更改</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation type="vanished">您正在更改日程的重複規則。</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation type="vanished">您正在刪除日程。</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation type="vanished">您確定要刪除此日程嗎？</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">刪 除</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">您要刪除此日程的所有重複，還是只刪除所選重複？</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation type="vanished">全部刪除</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation type="vanished">僅刪除此日程</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">您要刪除此日程的這個重複和所有將來重複，還是只刪除所選重複？</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation type="vanished">刪除所有將來日程</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation type="vanished">您正在更改重複日程。</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation type="vanished">您要更改此日程的僅這一個重複，還是更改它的所有重複？</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="vanished">全部日程</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation type="vanished">僅此日程</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation type="vanished">您要更改此日程的這個重複和所有將來重複，還是只更改所選重複？</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation type="vanished">所有將來日程</translation>
    </message>
    <message>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation type="vanished">您選擇的是閏月，將按照農曆規則提醒</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">確 定</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation type="vanished">年</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">月</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">日</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">編輯</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">刪除</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">全天</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation type="vanished">找不到結果</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation type="vanished">全天</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <source>Manual</source>
        <translation type="vanished">手動</translation>
    </message>
    <message>
        <source>15 mins</source>
        <translation type="vanished">每15分鐘</translation>
    </message>
    <message>
        <source>30 mins</source>
        <translation type="vanished">每30分鐘</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation type="vanished">每1小時</translation>
    </message>
    <message>
        <source>24 hours</source>
        <translation type="vanished">每24小時</translation>
    </message>
    <message>
        <source>Sync Now</source>
        <translation type="vanished">立即同步</translation>
    </message>
    <message>
        <source>Last sync</source>
        <translation type="vanished">最近同步時間</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="vanished">週一</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">週日</translation>
    </message>
    <message>
        <source>12-hour clock</source>
        <translation type="vanished">12小時制</translation>
    </message>
    <message>
        <source>24-hour clock</source>
        <translation type="vanished">24小時制</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <source>(%1 mins)</source>
        <translation type="vanished">(%1分鐘)</translation>
    </message>
    <message>
        <source>(%1 hour)</source>
        <translation type="vanished">(%1小時)</translation>
    </message>
    <message>
        <source>(%1 hours)</source>
        <translation type="vanished">(%1小時)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">年</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">月</translation>
    </message>
    <message>
        <source>W</source>
        <translation type="vanished">週</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">日</translation>
    </message>
    <message>
        <source>Search events and festivals</source>
        <translation type="vanished">搜尋日程/節日</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation type="vanished">日</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation type="vanished">一</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation type="vanished">二</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation type="vanished">三</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation type="vanished">四</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation type="vanished">五</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation type="vanished">六</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation type="vanished">週</translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="vanished">年</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">全天</translation>
    </message>
    <message>
        <source>No event</source>
        <translation type="vanished">無日程</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">年</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">日曆</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation type="vanished">日曆是一款查看日期、管理日程的小工具。</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">日曆</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="vanished">管理</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="vanished">隱私政策</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation type="vanished">正在同步...</translation>
    </message>
    <message>
        <source>Sync successful</source>
        <translation type="vanished">同步成功</translation>
    </message>
    <message>
        <source>Sync failed, please try later</source>
        <translation type="vanished">同步失敗，請稍後再試</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">全天</translation>
    </message>
</context>
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>工作</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>生活</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>關 閉</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>提前1天提醒</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>明天提醒</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>稍後提醒</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15分鐘後</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1小時後</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4小時後</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>明天</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>日程提醒</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 至 %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">編輯</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">刪除</translation>
    </message>
    <message>
        <source>New event</source>
        <translation type="vanished">建立日程</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">建立日程</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <source>You are deleting an event type.</source>
        <translation type="vanished">您正在刪除日程類型。</translation>
    </message>
    <message>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation type="vanished">此日程類型下的所有日程都會刪除且不可恢復。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">取 消</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">刪 除</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Account settings</source>
        <translation type="vanished">帳戶設定</translation>
    </message>
    <message>
        <source>Account</source>
        <translation type="vanished">帳戶</translation>
    </message>
    <message>
        <source>Select items to be synced</source>
        <translation type="vanished">設定您的同步項</translation>
    </message>
    <message>
        <source>Events</source>
        <translation type="vanished">日程</translation>
    </message>
    <message>
        <source>General settings</source>
        <translation type="vanished">一般設定</translation>
    </message>
    <message>
        <source>Sync interval</source>
        <translation type="vanished">同步頻率</translation>
    </message>
    <message>
        <source>Manage calendar</source>
        <translation type="vanished">日曆管理</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation type="vanished">日曆帳戶</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation type="vanished">日程類型</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">通用</translation>
    </message>
    <message>
        <source>First day of week</source>
        <translation type="vanished">每星期開始於</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="vanished">時間</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="vanished">今天</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="vanished">今天</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <source>New event type</source>
        <translation type="vanished">新增日程類型</translation>
    </message>
    <message>
        <source>Edit event type</source>
        <translation type="vanished">編輯日程類型</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">名稱：</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="vanished">顏色：</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">儲 存</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation type="vanished">名稱不能設置為全空格，請修改</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation type="vanished">名稱不能為空</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation type="vanished">幫助</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation type="vanished">刪除日程</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">複製</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">剪下</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">貼上</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">刪除</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation type="vanished">全選</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">年</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">月</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <source>Go</source>
        <comment>button</comment>
        <translation type="vanished">跳 轉</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <source>Sign In</source>
        <comment>button</comment>
        <translation type="vanished">登 入</translation>
    </message>
    <message>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation type="vanished">退出登入</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation type="vanished">年</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="vanished">今天</translation>
    </message>
</context>
</TS>